@@ -30,8 +30,12 @@ PART2TIMER = {
     'apt-compat': 'apt-daily',
     'dpkg': 'dpkg-db-backup',
     'plocate': 'plocate-updatedb',
+    'sysstat': 'sysstat-summary',
 }
 
+CROND2TIMER = {
+    'sysstat': 'sysstat-collect',
+}
 
 for pgm in ('/usr/sbin/sendmail', '/usr/lib/sendmail'):
     if os.path.exists(pgm):
@@ -534,8 +538,10 @@ def main():
     CRONTAB_FILES = files('/etc/cron.d')
     for filename in CRONTAB_FILES:
         basename = os.path.basename(filename)
+        basename_distro = CROND2TIMER.get(basename, basename)
         masked = False
         for unit_file in ('@unitdir@/%s.timer' % basename,
+                          '@unitdir@/%s.timer' % basename_distro,
                           '/etc/systemd/system/%s.timer' % basename,
                           '/run/systemd/system/%s.timer' % basename):
             if os.path.exists(unit_file):
@@ -572,7 +578,7 @@ def main():
         job_template['u'] = 'root'
         job_template['e'] = ''
         i = 0
-        for period in ['hourly', 'daily', 'weekly', 'monthly']:
+        for period in ['hourly', 'daily', 'weekly', 'monthly', 'yearly']:
             i = i + 1
             job_template['b'] = i * 5
             directory = '/etc/cron.' + period
